@@ -772,7 +772,7 @@ _atspi_send_event (AtspiEvent *e)
 }
 
 DBusHandlerResult
-atspi_dbus_handle_event (DBusConnection *bus, DBusMessage *message, void *data)
+_atspi_dbus_handle_event (DBusConnection *bus, DBusMessage *message, void *data)
 {
   char *detail = NULL;
   const char *category = dbus_message_get_interface (message);
